==> thunderdome-0.2.5.tar.gz: thunderdome-0.2.5/thunderdome/tests/groovy/test_scanner.py <==
# Copyright (c) 2012-2013 SHIFT.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import os

from unittest import TestCase
from thunderdome.gremlin import parse

class GroovyScannerTest(TestCase):
    """
    Test Groovy language scanner
    """
    
    def test_parsing_complicated_function(self):
        groovy_file = os.path.join(os.path.dirname(__file__), 'test.groovy')
        result = parse(groovy_file)
        assert len(result[6].body.split('\n')) == 8

        result_map = {x.name: x for x in result}
        assert 'get_self' in result_map
        assert 'return_value' in result_map
        assert 'long_func' in result_map

==> thunderdome-0.2.9.tar.gz: thunderdome-0.2.9/thunderdome/tests/groovy/test_scanner.py <==
# Copyright (c) 2012-2013 SHIFT.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import os

from unittest import TestCase
from thunderdome.gremlin import parse

class GroovyScannerTest(TestCase):
    """
    Test Groovy language scanner
    """
    
    def test_parsing_complicated_function(self):
        groovy_file = os.path.join(os.path.dirname(__file__), 'groovy_test_model.groovy')
        result = parse(groovy_file)
        assert len(result[6].body.split('\n')) == 8

        result_map = {x.name: x for x in result}
        assert 'get_self' in result_map
        assert 'return_value' in result_map
        assert 'long_func' in result_map
